import UIKit

struct Results: Codable {
    let items: [Item]
}

struct Item: Codable, Identifiable {
	let id: String
	let vid: VID
    let snippet: Snippet
	
	enum CodingKeys: String, CodingKey {
		case id = "etag"
		case vid = "id"
		case snippet
	}
}

struct VID: Codable {
	let videoId: String
}

struct Snippet: Codable {
    let title, description: String
    let thumbnails: Thumbnails
}

struct Thumbnails: Codable {
	let `default`: Thumbnail
}

struct Thumbnail: Codable {
    let url: String
}


// APIKeyを設定
let APIKey = "XXXXXXXXXXXXXX"
// 検索するキーワード
let keyword = "Giulietta Machine"
// 最大検索数
let maxResults = 5

// リクエスト用の文字列を生成
guard let urlStr = "https://www.googleapis.com/youtube/v3/search?part=snippet&q=\(keyword)&type=video&maxResults=\(maxResults)&key=\(APIKey)".addingPercentEncoding(withAllowedCharacters: NSCharacterSet.urlQueryAllowed)
	else {
		fatalError("URL String Error")
}

// URLに変換する
guard let url = URL(string:urlStr) else {
	fatalError("Could'nt convert to url")
}

// YouTube Data APIにリクエストを送る
let task = URLSession.shared.dataTask(with: url) { data, response, error in
	if let jsonData = data {
		// JSONデータをデコードする
		let results:Results?
		do {
			results = try JSONDecoder().decode(Results.self, from: jsonData)
		}
		catch {
			fatalError("Couldn't decode JSON data")
		}

		for video in results!.items {
			print(video)
		}
		
	} else {
		fatalError("Couldn't decode JSON Data.")
	}
}
task.resume()
